
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.47'
version = '1.2.47'
full_version = '1.2.47'
git_revision = '0627083873dc13fcb1521718b73775d7a0b48e85'
release = True

if not release:
    version = full_version
    short_version += ".dev"
